@@ -6,7 +6,7 @@ use Mojolicious::Plugin::AssetPack::Asset::Null;
 use Mojolicious::Plugin::AssetPack::Store;
 use Mojolicious::Plugin::AssetPack::Util qw(diag has_ro load_module DEBUG);
 
-our $VERSION = '1.35';
+our $VERSION = '1.36';
 
 my %TAG_TEMPLATE;
 $TAG_TEMPLATE{css} = [qw(link rel stylesheet href)];
@@ -151,8 +151,7 @@ sub _process {
 
   for my $asset (@$assets) {
     if (my $prev = $self->{by_topic}{$topic}) {
-      delete $self->{by_checksum}{$_->checksum} for @$prev;
-      delete $asset->{$_} for qw(checksum format mtime);
+      delete $asset->{$_} for qw(checksum format);
       $asset->content($self->store->asset($asset->url));
     }
     $asset->checksum;
@@ -164,7 +163,7 @@ sub _process {
       local $pipe->{topic} = $topic;
       diag '%s->%s("%s")', ref $pipe, $method, $topic if DEBUG;
       $pipe->$method($assets);
-      push @{$self->{asset_paths}}, $_->path for @$assets;
+      push @{$self->{asset_paths}}, $_->path->to_string for grep { $_->path } @$assets;
     }
   }
 
@@ -278,7 +277,7 @@ Mojolicious::Plugin::AssetPack - Compress and convert css, less, sass, javascrip
 
 =head1 VERSION
 
-1.35
+1.36
 
 =head1 SYNOPSIS
 
